PostgreSQL schema introspection and caching.
This module provides functionality to discover and cache database schema metadata including tables, columns, relationships, and functions.
Structs
- Column
- A table column.
- Junction
- Junction table for M2M relationships.
- Routine
- A stored function or procedure.
- Routine
Param - A function parameter.
- Schema
Cache - Cached PostgreSQL schema metadata.
- Schema
Cache Ref - Thread-safe schema cache wrapper.
- Table
- A database table or view.
Enums
- Cardinality
- Relationship cardinality.
- Func
Volatility - Function volatility category.
- Relationship
- A relationship between tables.
- RetType
- Function return type.
Type Aliases
- Column
Map - Map of column name to column.
- Relationships
Map - Map of (table, schema) to relationships.
- Routine
Map - Map of qualified identifier to routines (overloaded functions share name).
- Tables
Map - Map of qualified identifier to table.