pub enum FuncVolatility {
Immutable,
Stable,
Volatile,
}Expand description
Function volatility category.
Variants
Immutable
Function cannot modify database and always returns same result for same inputs
Stable
Function cannot modify database but result may change across queries
Volatile
Function can modify database
Implementations