Module schema_cache

Module schema_cache 

PostgreSQL schema introspection and caching.

This module provides functionality to discover and cache database schema metadata including tables, columns, relationships, and functions.

Structs

Column
A table column.
Junction
Junction table for M2M relationships.
Routine
A stored function or procedure.
RoutineParam
A function parameter.
SchemaCache
Cached PostgreSQL schema metadata.
SchemaCacheRef
Thread-safe schema cache wrapper.
Table
A database table or view.

Enums

Cardinality
Relationship cardinality.
FuncVolatility
Function volatility category.
Relationship
A relationship between tables.
RetType
Function return type.

Type Aliases

ColumnMap
Map of column name to column.
RelationshipsMap
Map of (table, schema) to relationships.
RoutineMap
Map of qualified identifier to routines (overloaded functions share name).
TablesMap
Map of qualified identifier to table.